Transaction

Struct Transaction 

pub struct Transaction {
Show 20 fields pub id: String, pub date: NaiveDate, pub amount: i64, pub memo: Option<String>, pub cleared: ClearedStatus, pub approved: bool, pub flag_color: Option<FlagColor>, pub flag_name: Option<String>, pub account_id: Uuid, pub payee_id: Option<Uuid>, pub account_name: Option<String>, pub payee_name: Option<String>, pub category_id: Option<Uuid>, pub category_name: Option<String>, pub matched_transaction_id: Option<String>, pub import_id: Option<String>, pub import_payee_name: Option<String>, pub import_payee_name_original: Option<String>, pub deleted: bool, pub subtransactions: Vec<Subtransaction>,
}
A plan transaction, excluding any pending transactions. Amounts are in milliunits (divide by 1000 for display).

id is a String rather than Uuid because upcoming scheduled transaction instances use a compound format {scheduled_uuid}_{date} (e.g. "abc123..._2025-06-01"). Regular posted transactions have standard UUID ids.

Fields

id: Stringdate: NaiveDateamount: i64memo: Option<String>cleared: ClearedStatusapproved: boolflag_color: Option<FlagColor>flag_name: Option<String>account_id: Uuidpayee_id: Option<Uuid>account_name: Option<String>payee_name: Option<String>category_id: Option<Uuid>category_name: Option<String>matched_transaction_id: Option<String>import_id: Option<String>import_payee_name: Option<String>import_payee_name_original: Option<String>deleted: boolsubtransactions: Vec<Subtransaction>