Client

Struct Client 

pub struct Client { /* private fields */ }
Client is the YNAB API client. Use Client::new() to create one.

Implementations

Source

impl Client

pub fn get_accounts(&self, plan_id: PlanId) -> GetAccountsBuilder<'_>

Returns all accounts. The second return value is server knowledge for delta requests.

pub async fn get_account( &self, plan_id: PlanId, account_id: Uuid, ) -> Result<Account, Error>

Returns a single account.

Source

impl Client

pub async fn create_account( &self, plan_id: PlanId, account: SaveAccount, ) -> Result<Account, Error>

Creates a new account.

Source

impl Client

pub fn get_categories(&self, plan_id: PlanId) -> GetCategoriesBuilder<'_>

Returns all categories grouped by category group. Amounts (assigned, activity, available, etc.) are specific to the current plan month (UTC). The second return value is server knowledge for delta requests.

pub async fn get_category( &self, plan_id: PlanId, cat_id: Uuid, ) -> Result<Category, Error>

Returns a single category. Amounts (assigned, activity, available, etc.) are specific to the current plan month (UTC).

pub async fn get_category_for_month( &self, plan_id: PlanId, month: NaiveDate, cat_id: Uuid, ) -> Result<Category, Error>

Returns a single category for a specific plan month. Amounts (assigned, activity, available, etc.) are specific to the current plan month (UTC).

Source

impl Client

pub async fn create_category( &self, plan_id: PlanId, category: NewCategory, ) -> Result<(Category, i64), Error>

Creates a new category.

pub async fn create_category_group( &self, plan_id: PlanId, category_group: SaveCategoryGroup, ) -> Result<(CategoryGroup, i64), Error>

Creates a new category group.

pub async fn update_category( &self, plan_id: PlanId, category_id: Uuid, category: SaveCategory, ) -> Result<(Category, i64), Error>

Update a category.

pub async fn update_category_for_month( &self, plan_id: PlanId, month: NaiveDate, category_id: Uuid, category: SaveMonthCategory, ) -> Result<(Category, i64), Error>

Update a category for a specific month. Only budgeted (assigned) amount can be updated.`

pub async fn update_category_group( &self, plan_id: PlanId, category_group_id: Uuid, category_group: SaveCategoryGroup, ) -> Result<(CategoryGroup, i64), Error>

Update a category group.

Source

impl Client

pub fn new(api_key: impl Into<String>) -> Result<Self, Error>

Creates a new Client with the given Personal Access Token.

pub fn with_timeout(self, timeout: Duration) -> Result<Self, Error>

Sets the request timeout. Rebuilds the underlying HTTP client.

pub fn with_base_url(self, base_url: impl AsRef<str>) -> Result<Self, Error>

Overrides the base URL. Primarily useful for testing.

pub fn with_rate_limiter( self, requests_per_hour: usize, burst_volume: Option<usize>, ) -> Result<Self, Error>

Configures a token bucket rate limiter on the client. The YNAB API enforces a rolling window of 200 requests per hour.

requests_per_hour is the total allowed requests per hour. burst_volume optionally allows a number of requests to be made immediately before throttling begins. The effective sustained rate becomes requests_per_hour - burst_volume to account for burst consumption. If None, no burst is allowed and the full rate is sustained evenly.

Example: with_rate_limiter(200, Some(10)) allows 10 immediate requests, then throttles to 190 requests per hour.

Source

impl Client

pub fn get_months(&self, plan_id: PlanId) -> GetMonthsBuilder<'_>

Returns all plan months. The second return value is server knowledge for delta requests.

pub async fn get_month( &self, plan_id: PlanId, month: NaiveDate, ) -> Result<Month, Error>

Returns a single plan month.

Source

impl Client

pub fn get_money_movements( &self, plan_id: PlanId, ) -> GetMoneyMovementsBuilder<'_>

Returns all money movements. The second return value is server knowledge for delta requests.

pub async fn get_money_movements_by_month( &self, plan_id: PlanId, month: NaiveDate, ) -> Result<(Vec<MoneyMovement>, i64), Error>

Returns all money movements for a specific month. The second return value is server knowledge for delta requests.

pub fn get_money_movement_groups( &self, plan_id: PlanId, ) -> GetMoneyMovementGroupsBuilder<'_>

Returns all money movement groups. The second return value is server knowledge for delta requests.

pub async fn get_money_movement_groups_by_month( &self, plan_id: PlanId, month: NaiveDate, ) -> Result<(Vec<MoneyMovementGroup>, i64), Error>

Returns all money movement groups for a specific month. The second return value is server knowledge for delta requests.

Source

impl Client

pub fn get_payees(&self, plan_id: PlanId) -> GetPayeesBuilder<'_>

Returns all payees. The second return value is server knowledge for delta requests.

pub async fn get_payee( &self, plan_id: PlanId, payee_id: Uuid, ) -> Result<Payee, Error>

Returns a single payee.

pub async fn get_payee_locations( &self, plan_id: PlanId, ) -> Result<Vec<PayeeLocation>, Error>

Returns all payee locations.

pub async fn get_payee_locations_by_payee( &self, plan_id: PlanId, payee_id: Uuid, ) -> Result<Vec<PayeeLocation>, Error>

Returns all payee locations for a specified payee.

pub async fn get_payee_location( &self, plan_id: PlanId, location_id: Uuid, ) -> Result<PayeeLocation, Error>

Returns a single payee location.

Source

impl Client

pub async fn create_payee( &self, plan_id: PlanId, payee: PostPayee, ) -> Result<(Payee, i64), Error>

Creates a new payee. Returns the created payee and server knowledge for delta requests.

pub async fn update_payee( &self, plan_id: PlanId, payee_id: Uuid, payee: SavePayee, ) -> Result<(Payee, i64), Error>

Updates an existing payee. Returns the updated payee and server knowledge for delta requests.

Source

impl Client

pub fn get_plans(&self) -> GetPlansBuilder<'_>

Returns plans list with summary information.

pub async fn get_plan_settings( &self, plan_id: PlanId, ) -> Result<PlanSettings, Error>

Returns settings for a plan.

pub fn get_plan(&self, plan_id: PlanId) -> GetPlanBuilder<'_>

Returns a single plan with all related entities. This resource is effectively a full plan export. The second return value is server knowledge for delta requests.

Source

impl Client

pub fn get_transactions(&self, plan_id: PlanId) -> GetTransactionsBuilder<'_>

Returns plan transactions, excluding any pending transactions. The second return value is server knowledge for delta requests.

pub async fn get_transaction( &self, plan_id: PlanId, transaction_id: &Uuid, ) -> Result<(Transaction, i64), Error>

Returns a single transaction.

pub fn get_transactions_by_account( &self, plan_id: PlanId, account_id: Uuid, ) -> GetTransactionsBuilder<'_>

Returns all transactions for a specified account, excluding any pending transactions.

pub fn get_transactions_by_category( &self, plan_id: PlanId, category_id: Uuid, ) -> GetTransactionsBuilder<'_>

Returns all transactions for a specified category, excluding any pending transactions.

pub fn get_transactions_by_payee( &self, plan_id: PlanId, payee_id: Uuid, ) -> GetTransactionsBuilder<'_>

Returns all transactions for a specified payee, excluding any pending transactions.

pub fn get_transactions_by_month( &self, plan_id: PlanId, month: NaiveDate, ) -> GetTransactionsBuilder<'_>

Returns all transactions for a specified month, excluding any pending transactions.

Source

impl Client

pub fn get_scheduled_transactions( &self, plan_id: PlanId, ) -> GetScheduledTransactionsBuilder<'_>

Returns all scheduled transactions. The second return value is server knowledge for delta requests.

pub async fn get_scheduled_transaction( &self, plan_id: PlanId, transaction_id: Uuid, ) -> Result<ScheduledTransaction, Error>

Returns a single scheduled transaction.

Source

impl Client

pub async fn delete_transaction( &self, plan_id: PlanId, tx_id: Uuid, ) -> Result<(Transaction, i64), Error>

Delete a transaction. Returns deleted transaction and server_knowledge for delta requests

pub async fn import_transactions( &self, plan_id: PlanId, ) -> Result<Vec<Uuid>, Error>

Imports available transactions on all linked accounts for the given plan. The response for this endpoint contains the transaction ids that have been imported.

Source

impl Client

pub async fn create_transaction( &self, plan_id: PlanId, transaction: NewTransaction, ) -> Result<SaveTransactionsResponse, Error>

Creates a single transaction. Returns the full save response including server knowledge.

pub async fn create_transactions( &self, plan_id: PlanId, transactions: Vec<NewTransaction>, ) -> Result<SaveTransactionsResponse, Error>

Creates multiple transactions. Returns the full save response including server knowledge.

pub async fn update_transactions( &self, plan_id: PlanId, transactions: Vec<SaveTransactionWithIdOrImportId>, ) -> Result<SaveTransactionsResponse, Error>

Updates multiple transactions. Returns the full save response including server knowledge.

pub async fn update_transaction( &self, plan_id: PlanId, tx_id: Uuid, transaction: ExistingTransaction, ) -> Result<(Transaction, i64), Error>

Updates a single transaction. Returns the updated transaction and server knowledge.

pub async fn create_scheduled_transaction( &self, plan_id: PlanId, scheduled_transaction: SaveScheduledTransaction, ) -> Result<ScheduledTransaction, Error>

Creates a scheduled transaction.

pub async fn update_scheduled_transaction( &self, plan_id: PlanId, scheduled_transaction_id: Uuid, scheduled_transaction: SaveScheduledTransaction, ) -> Result<ScheduledTransaction, Error>

Updates a scheduled transaction.

pub async fn delete_scheduled_transaction( &self, plan_id: PlanId, scheduled_transaction_id: Uuid, ) -> Result<ScheduledTransaction, Error>

Deletes a scheduled transaction.

Source

impl Client

pub async fn get_user(&self) -> Result<User, Error>

Returns authenticated user information.